@@ -2,9 +2,13 @@ setMethodS3("allocateFromCdf", "AromaCellMatchScoreFile", function(static, cdf,
   # Argument 'cdf':
   cdf <- Arguments$getInstanceOf(cdf, "AffymetrixCdfFile");
 
-  tags <- strsplit(tags, split=",", fixed=TRUE)[[1]];
+  # Argument 'tags':
+  tags <- Arguments$getTags(tags, collapse=NULL);
+
   chipType <- getChipType(cdf);
-  parts <- strsplit(chipType, split=",", fixed=TRUE)[[1]];
+  parts <- strsplit(chipType, split=",", fixed=TRUE);
+  parts <- unlist(parts, use.names=FALSE);
+
   tags[tags == "*"] <- paste(parts[-1], collapse=",");
   chipType <- parts[1];
   chipType <- gsub(",monocell", "", chipType);
@@ -20,6 +24,9 @@ setMethodS3("allocateFromCdf", "AromaCellMatchScoreFile", function(static, cdf,
 
 ############################################################################
 # HISTORY:
+# 2010-03-14 [HB]
+# o BUG FIX: allocateFromCdf() of AromaCellMatchScoreFile would drop all
+#   but the first tag.
 # 2009-02-22 [HB]
 # o Forgot to make allocateFromCdf() of AromaCellMatchScoreFile static.
 # 2009-02-10 [HB]
